==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/TemplateSectionHeaderCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SectionHeaderCellInfoDescriptionMetadata } from "./SectionHeaderCellInfoDescriptionMetadata";
import { TemplateSectionHeaderCellInfoDescription } from "./TemplateSectionHeaderCellInfoDescription";
/**
 * @hidden
 */
export let TemplateSectionHeaderCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class TemplateSectionHeaderCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (TemplateSectionHeaderCellInfoDescriptionMetadata.a == null) {
                TemplateSectionHeaderCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TemplateSectionHeaderCellInfoDescriptionMetadata.c(TemplateSectionHeaderCellInfoDescriptionMetadata.a);
            }
            if (a.j(TemplateSectionHeaderCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.y(TemplateSectionHeaderCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            SectionHeaderCellInfoDescriptionMetadata.c(a);
        }
        static d(a) {
            TemplateSectionHeaderCellInfoDescriptionMetadata.b(a);
            a.aa("TemplateSectionHeaderCellInfo", () => new TemplateSectionHeaderCellInfoDescription());
            a.z("TemplateSectionHeaderCellInfo", TemplateSectionHeaderCellInfoDescriptionMetadata.a);
        }
    }
    TemplateSectionHeaderCellInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(TemplateSectionHeaderCellInfoDescriptionMetadata, 'TemplateSectionHeaderCellInfoDescriptionMetadata');
    TemplateSectionHeaderCellInfoDescriptionMetadata.a = null;
    return TemplateSectionHeaderCellInfoDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/TemplateSectionHeaderCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SectionHeaderCellInfoDescriptionMetadata } from "./SectionHeaderCellInfoDescriptionMetadata";
import { TemplateSectionHeaderCellInfoDescription } from "./TemplateSectionHeaderCellInfoDescription";
/**
 * @hidden
 */
export let TemplateSectionHeaderCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class TemplateSectionHeaderCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (TemplateSectionHeaderCellInfoDescriptionMetadata.a == null) {
                TemplateSectionHeaderCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TemplateSectionHeaderCellInfoDescriptionMetadata.c(TemplateSectionHeaderCellInfoDescriptionMetadata.a);
            }
            if (a.k(TemplateSectionHeaderCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.aa(TemplateSectionHeaderCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            SectionHeaderCellInfoDescriptionMetadata.c(a);
        }
        static d(a) {
            TemplateSectionHeaderCellInfoDescriptionMetadata.b(a);
            a.ac("TemplateSectionHeaderCellInfo", () => new TemplateSectionHeaderCellInfoDescription());
            a.ab("TemplateSectionHeaderCellInfo", TemplateSectionHeaderCellInfoDescriptionMetadata.a);
        }
    }
    TemplateSectionHeaderCellInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(TemplateSectionHeaderCellInfoDescriptionMetadata, 'TemplateSectionHeaderCellInfoDescriptionMetadata');
    TemplateSectionHeaderCellInfoDescriptionMetadata.a = null;
    return TemplateSectionHeaderCellInfoDescriptionMetadata;
})();
